#[cfg(test)]
mod tests;

use dir_odt_to_pdf::{
    directory_processor::DirectoryProcessor,
    error::Result,
    info, log_detail, log_timed,
    logging::{LogConfig, init_logging},
};
use log::LevelFilter;
use std::path::PathBuf;
use structopt::StructOpt;

#[derive(Debug, StructOpt)]
#[structopt(
    name = "dir-odt-to-pdf",
    about = "Convert ODT files to PDF in a directory"
)]
struct Opt {
    /// Source directory containing ODT files
    #[structopt(parse(from_os_str))]
    source_dir: PathBuf,

    /// Target directory for PDF files
    #[structopt(parse(from_os_str))]
    target_dir: PathBuf,

    /// Log file path (optional)
    #[structopt(parse(from_os_str), long)]
    log_file: Option<PathBuf>,

    /// Log level (trace, debug, info, warn, error)
    #[structopt(long, default_value = "info")]
    log_level: LevelFilter,

    /// Append to existing log file instead of overwriting
    #[structopt(long)]
    append_log: bool,
}

fn main() -> Result<()> {
    let args = Opt::from_args();

    // Initialize logging
    let log_config = LogConfig {
        log_file: args.log_file,
        log_level: args.log_level,
        append_log: args.append_log,
    };

    // Initialize logging system
    init_logging(log_config)?;

    info!("Starting directory processing");
    log_detail!(
        log::Level::Info,
        "Source directory: {}",
        args.source_dir.display()
    );
    log_detail!(
        log::Level::Info,
        "Target directory: {}",
        args.target_dir.display()
    );

    let mut processor = DirectoryProcessor::new(args.source_dir, args.target_dir);

    // Process directory and measure time
    log_timed!(log::Level::Info, "Directory processing", {
        processor.process()?
    });

    info!("Processing completed successfully");
    Ok(())
}
